==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DawkaLekKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DawkaLekKey extends GenericDPSObject {
    /**
     * DAWKA_LEK.DAWKOWANIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dawkowanieId;

    /**
     * DAWKA_LEK.PORA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poraId;

    /**
     * DAWKA_LEK.LEK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long lekId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DAWKA_LEK.DAWKOWANIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDawkowanieId() {
        return dawkowanieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DAWKA_LEK.DAWKOWANIE_ID
     *
     * @param dawkowanieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDawkowanieId(Long dawkowanieId) {
        this.dawkowanieId = dawkowanieId;
    }

    /**
     * @return DAWKA_LEK.PORA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoraId() {
        return poraId;
    }

    /**
     * DAWKA_LEK.PORA_ID
     *
     * @param poraId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoraId(Long poraId) {
        this.poraId = poraId;
    }

    /**
     * @return DAWKA_LEK.LEK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * DAWKA_LEK.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DawkaLekKey other = (DawkaLekKey) that;
        return (this.getDawkowanieId() == null ? other.getDawkowanieId() == null : this.getDawkowanieId().equals(other.getDawkowanieId()))
            && (this.getPoraId() == null ? other.getPoraId() == null : this.getPoraId().equals(other.getPoraId()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDawkowanieId() == null) ? 0 : getDawkowanieId().hashCode());
        result = prime * result + ((getPoraId() == null) ? 0 : getPoraId().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dawkowanieId=").append(dawkowanieId);
        sb.append(", poraId=").append(poraId);
        sb.append(", lekId=").append(lekId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DawkaLekKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DawkaLekKey extends GenericDPSObject {
    /**
     * DAWKA_LEK.DAWKOWANIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dawkowanieId;

    /**
     * DAWKA_LEK.PORA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poraId;

    /**
     * DAWKA_LEK.LEK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long lekId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DAWKA_LEK.DAWKOWANIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDawkowanieId() {
        return dawkowanieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DAWKA_LEK.DAWKOWANIE_ID
     *
     * @param dawkowanieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDawkowanieId(Long dawkowanieId) {
        this.dawkowanieId = dawkowanieId;
    }

    /**
     * @return DAWKA_LEK.PORA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoraId() {
        return poraId;
    }

    /**
     * DAWKA_LEK.PORA_ID
     *
     * @param poraId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoraId(Long poraId) {
        this.poraId = poraId;
    }

    /**
     * @return DAWKA_LEK.LEK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * DAWKA_LEK.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DawkaLekKey other = (DawkaLekKey) that;
        return (this.getDawkowanieId() == null ? other.getDawkowanieId() == null : this.getDawkowanieId().equals(other.getDawkowanieId()))
            && (this.getPoraId() == null ? other.getPoraId() == null : this.getPoraId().equals(other.getPoraId()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDawkowanieId() == null) ? 0 : getDawkowanieId().hashCode());
        result = prime * result + ((getPoraId() == null) ? 0 : getPoraId().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dawkowanieId=").append(dawkowanieId);
        sb.append(", poraId=").append(poraId);
        sb.append(", lekId=").append(lekId);
        sb.append("]");
        return sb.toString();
    }
}
